@@ -74,6 +74,7 @@ def test_bsplines(tmp_path, testnum):
         in_data=test1.outputs.out_field,
         in_mask=str(tmp_path / "target.nii.gz"),
         bs_spacing=[(4, 6, 8)],
+        zooms_min=0,
         recenter=False,
         ridge_alpha=1e-4,
     ).run()
@@ -88,6 +89,7 @@ def test_topup_coeffs(tmpdir, testdata_dir):
     result = TOPUPCoeffReorient(
         in_coeff=str(testdata_dir / "topup-coeff.nii.gz"),
         fmap_ref=str(testdata_dir / "epi.nii.gz"),
+        pe_dir="j",
     ).run()
 
     nii = nb.load(result.outputs.out_coeff)
@@ -102,11 +104,12 @@ def test_topup_coeffs(tmpdir, testdata_dir):
         TOPUPCoeffReorient(
             in_coeff="failing.nii.gz",
             fmap_ref=str(testdata_dir / "epi.nii.gz"),
+            pe_dir="j",
         ).run()
 
     # Test automatic output file name generation, just for coverage
     with pytest.raises(ValueError):
-        _fix_topup_fieldcoeff("failing.nii.gz", str(testdata_dir / "epi.nii.gz"))
+        _fix_topup_fieldcoeff("failing.nii.gz", str(testdata_dir / "epi.nii.gz"), "i")
 
 
 @pytest.mark.skipif(os.getenv("GITHUB_ACTIONS") == "true", reason="this is GH Actions")
@@ -119,15 +122,13 @@ def test_topup_coeffs_interpolation(tmpdir, testdata_dir):
         pe_dir="j-",
         ro_time=1.0,
     ).run()
+    interpolated = nb.as_closest_canonical(
+        nb.load(result.outputs.out_field)
+    ).get_fdata()
+    reference = nb.as_closest_canonical(
+        nb.load(testdata_dir / "topup-field.nii.gz")
+    ).get_fdata()
     assert (
-        np.sqrt(
-            np.mean(
-                (
-                    nb.load(result.outputs.out_field).get_fdata()
-                    - nb.load(testdata_dir / "topup-field.nii.gz").get_fdata()
-                )
-                ** 2
-            )
-        )
+        np.sqrt(np.mean((interpolated - reference) ** 2))
         < 3
     )
